@@ -19,4 +19,5 @@ affstats -V 2> /dev/null
 affverify -V 2> /dev/null
 affxml -V 2> /dev/null
 
-# affuse don't have a -v or -V option.
+# affuse doesn't have a -v or -V option. Using an alternative test.
+affuse 2>&1 | grep 'Usage: affuse'
